<?php

/**
 * @package: patterns
 * @author: Yevhen Odynets
 * @date: 2025-07-06
 * @time: 13:55
 */

declare(strict_types = 1);

namespace Pattern\Behavioral\Observer;

use SplObjectStorage;
use SplObserver;
use SplSubject;

class User implements SplSubject
{
    /**
     * @var string
     */
    private string $name;

    /**
     * @var SplObjectStorage
     */
    private SplObjectStorage $observers;

    public function __construct()
    {
        $this->observers = new SplObjectStorage();
    }

    /**
     * Attach an observer
     */
    public function attach(SplObserver $observer): void
    {
        $this->observers->attach($observer);
    }

    /**
     * Detach an observer
     */
    public function detach(SplObserver $observer): void
    {
        $this->observers->detach($observer);
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @param  string  $name
     *
     * @return void
     */
    public function setName(string $name): void
    {
        $this->name = $name;

        $this->notify();
    }

    /**
     * Notify an observer
     */
    public function notify(): void
    {
        /** @var SplObserver $observer */
        foreach ($this->observers as $observer) {
            var_dump($observer);
            $observer->update($this);
        }
    }

}
