<?php

/**
 * @package: patterns
 * @author: Yevhen Odynets
 * @date: 2025-07-04
 * @time: 01:49
 */

declare(strict_types = 1);

namespace Pattern\Creational\Builder;

/**
 * The Director is only responsible for executing the building steps in a
 * particular sequence. It is helpful when producing Big Macs according to a
 * specific order or configuration. Strictly speaking, the Director class is
 * optional, since the client can control builders directly.
 */
class Director
{
    /**
     * @var BigMacBuilder
     */
    private BigMacBuilder $builder;

    /**
     * The Director works with any builder instance that the client code passes
     * to it. This way, the client code may alter the final type of the newly
     * assembled product.
     */
    public function setBuilder(BigMacBuilder $builder): void
    {
        $this->builder = $builder;
    }

    /**
     * The Director can construct several product variations using the same
     * building steps.
     */
    public function regularBigMac(): void
    {
        $this->builder->produceBun();
        $this->builder->produceMeat();
        $this->builder->produceSauce();
        $this->builder->produceLettuce();
        $this->builder->produceCheese();
        $this->builder->producePickles();
        $this->builder->produceOnions();
    }

    public function veganBigMac(): void
    {
        $this->builder->produceVeganBun();
        $this->builder->produceVeganMeat();
        $this->builder->produceVeganSauce();
        $this->builder->produceLettuce();
        $this->builder->produceVeganCheese();
        $this->builder->producePickles();
        $this->builder->produceOnions();
    }
}
