<?php

/**
 * @package: patterns
 * @author: Yevhen Odynets
 * @date: 2025-07-03
 * @time: 22:38
 */

declare(strict_types = 1);

namespace Pattern\Structural\Adapter;

use JsonException;

final readonly class XMLToPHPArrayReportAdapter implements PHPArrayReportInterfaceAdapter
{
    public function __construct(private XMLReport $report) {}


    /**
     * @throws JsonException
     */
    public function getData(): array
    {
        $xmlData = $this->report->buildXML();
        $xml = simplexml_load_string($xmlData);
        $json = json_encode($xml, JSON_THROW_ON_ERROR);

        return json_decode($json, true, 512, JSON_THROW_ON_ERROR);
    }
}
